@@ -1,6 +1,8 @@
+import sys
+sys.path.insert(0, '/Users/dylanwootton/Documents/GitHub/altair/altair')
 import altair as alt
 from .distributional import hist
-from .relational import scatterplot
+from .relational.relational import scatterplot
 import numpy as np
 
 def pairplot(data=None,variables=None):
